#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-toml%{psuffix}
Version:        0.10.2
Release:        3.12
Summary:        Python module which parses and emits TOML
License:        MIT
URL:            https://github.com/uiri/toml
Source:         https://files.pythonhosted.org/packages/source/t/toml/toml-%{version}.tar.gz
# Untagged test data https://github.com/uiri/toml/issues/232
Source1:        https://github.com/BurntSushi/toml-test/archive/280497f.tar.gz#/toml-test-280497f.tar.gz
# Missing file https://github.com/uiri/toml/pull/231
Source2:        https://raw.githubusercontent.com/uiri/toml/%{version}/test.toml
BuildRequires:  %{python_module setuptools}
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module pytest}
# python36-numpy is no longer available in Tumbleweed (NEP 29), tests are automatically skipped if not installed
BuildRequires:  %{python_module numpy if (%python-base without python36-base)}
%endif
%python_subpackages

%description
Python toml allows to parse and create toml configuration files.
See below the toml specification link.

Usage
toml.loads --- takes a string to be parsed as toml and returns
the corresponding dictionary
toml.dumps --- takes a dictionary and returns a string which
is the contents of the corresponding toml file.

There are other functions which can be used to dump and load various
fragments of toml but dumps and loads will cover most usage.

Current Version of TOML Specification
https://github.com/mojombo/toml/blob/v0.4.0/README.md

%prep
%setup -q -n toml-%{version}
tar -xzf %{SOURCE1}
ln -s toml-test*/ toml-test
cp %{SOURCE2} .

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
export LANG=en_US.UTF-8
%pytest
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}
%endif

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sun Feb 14 2021 Ben Greiner <code@bnavigator.de>
- Don't test NumPy with python36 flavor (NumPy 1.20 in TW dropped
  Python 3.6, NEP 29), tests are automatically skipped if not
  installed.
* Thu Nov 19 2020 Martin Liška <mliska@suse.cz>
- Update to 0.10.2:
  Fix a ValueError: Circular reference detected for empty {}
* Mon Aug 31 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to multibuild to not cycle with numpy
* Mon Jun  8 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.10.1
  * update testdata
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use pytest macro directly
* Sat Feb 23 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v0.10.0
  * Changes see https://github.com/uiri/toml/compare/0.9.4...0.10.0
  * Includes tests not previously included in source tarball
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue May 15 2018 bruno@ioda-net.ch
- Update to version 0.9.4
  + Changes see https://github.com/uiri/toml/compare/0.9.3...0.9.4
  + Contain again test which are run
- Packaging
  + spec-cleaner minimal (date, license)
  + Resurection to be included in d:l:p and Factory to be used
  by Cloud people and others
* Thu Dec 14 2017 bruno@ioda-net.ch
- Update to version 0.9.3.1 (no real changelog)
  Changes see https://github.com/uiri/toml/compare/0.9.2...0.9.3
- Packaging hardcode version in setup (tarball has only 0.9.3)
  + Add comment about test. None are executed, upstream has removed
    them from tarball (Work in progress)
* Thu Oct 26 2017 dmueller@suse.com
- remove python-coverage runtime requires
* Fri Jul 28 2017 bruno@ioda-net.ch
- Fix define line for build on Leap
* Wed Jun  7 2017 bruno@ioda-net.ch
- Move to singlespec packaging
- Update copyright year
- Add fdupes
* Tue Sep 20 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.9.2:
  * Use xrange (_range) in Python 2.
  * Prefix internal object/function names with an underscore.
  * Fix candidate groups handling.
  * Fix digit matching.
  * Fix usage of isdigit.
  * Optimize use of regexps (precompile, single-regexp substitution)
  * Fix code style.
  * Peephole optimizations.
  * Merge #51: Do not raise base Exception.
  * Remove dead code.
  * Fix inadvertently broken long integer test
  * s.decode should assign its result to s.
  * Remove unnecessary indent level/else branches
  * Fix #43 by adding Z timezone. tzinfos don't do DST
  * Fix UTC offsets specified as hours and minutes
  * update test command
  * add travis testing
  * Update copyright notice. Update toml-test repo in README
  * Close #42 and simplify. Manual testing shows this works.
  * Support } whithin string in inline objects within arrays
  * Remove test toml files
  * Clean load_inline_objects
  * fix for array in inlinetable
  * Handle commas inside strings within inline objects
  * Fix multiline-string and raw-multiline-string tests
  * Fix key-equals-nospace test
  * Add support for inline objects inside arrays
  * Add support for inline objects
* Sun May  8 2016 arun@gmx.de
- specfile:
  * changed to https for source url
  * updated source url to files.pythonhosted.org
* Wed Aug 19 2015 bruno@ioda-net.ch
- Initial packaging on obs for python3
  changes are stored in README.rst
